@@ -795,7 +795,9 @@ if ($type eq 'deb') {
                     to_file    => '/dev/null',
                     wait_child => 1,
                     chdir      => "$diri/$sdiri",
-                    nocheck    => 1
+                    no_check   => 1,
+                    # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+                    nocheck => 1,
                 );
                 if (-d "$diri/$sdiri/$filename") {
                     move "$diri/$sdiri/$filename", "$diri/$sdiri/$unpacked";
@@ -823,7 +825,9 @@ if ($type eq 'deb') {
         exec       => \@command,
         to_file    => $filename,
         wait_child => 1,
-        nocheck    => 1
+        no_check   => 1,
+        # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+        nocheck => 1,
     );
 
     if ($have_diffstat and $show_diffstat) {
@@ -1218,7 +1222,9 @@ sub wdiff_control_files($$$$$) {
             to_string       => \$wdiff,
             error_to_string => \$wdiff_error,
             wait_child      => 1,
-            nocheck         => 1
+            no_check        => 1,
+            # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+            nocheck => 1,
         );
         if ($? && ($? >> 8) != 1) {
             print "$wdiff_error\n";
